==> psa-8.2.0.tar.gz: psa-8.2.0/psa/admin/include/php/main/build-defs.h <==
/*                                                                -*- C -*-
   +----------------------------------------------------------------------+
   | PHP Version 5                                                        |
   +----------------------------------------------------------------------+
   | Copyright (c) 1997-2004 The PHP Group                                |
   +----------------------------------------------------------------------+
   | This source file is subject to version 3.0 of the PHP license,       |
   | that is bundled with this package in the file LICENSE, and is        |
   | available through the world-wide-web at the following url:           |
   | http://www.php.net/license/3_0.txt.                                  |
   | If you did not receive a copy of the PHP license and are unable to   |
   | obtain it through the world-wide-web, please send a note to          |
   | license@php.net so we can mail you a copy immediately.               |
   +----------------------------------------------------------------------+
   | Author: Stig Sther Bakken <ssb@php.net>                             |
   +----------------------------------------------------------------------+
*/

/* $Id: build-defs.h.in,v 1.14 2004/01/08 17:33:04 sniper Exp $ */

#define CONFIGURE_COMMAND " './configure' '/usr/local/psa/admin/share/config.site' '/usr/local/psa/admin/etc/config.site'"
#define PHP_ADA_INCLUDE		""
#define PHP_ADA_LFLAGS		""
#define PHP_ADA_LIBS		""
#define PHP_APACHE_INCLUDE	""
#define PHP_APACHE_TARGET	""
#define PHP_FHTTPD_INCLUDE      ""
#define PHP_FHTTPD_LIB          ""
#define PHP_FHTTPD_TARGET       ""
#define PHP_CFLAGS		"$(CFLAGS_CLEAN) -prefer-non-pic -static"
#define PHP_DBASE_LIB		""
#define PHP_BUILD_DEBUG		""
#define PHP_GDBM_INCLUDE	""
#define PHP_HSREGEX		""
#define PHP_IBASE_INCLUDE	""
#define PHP_IBASE_LFLAGS	""
#define PHP_IBASE_LIBS		""
#define PHP_IFX_INCLUDE		""
#define PHP_IFX_LFLAGS		""
#define PHP_IFX_LIBS		""
#define PHP_INSTALL_IT		"mkdir -p //usr/home/builder/autobuilder/psa_aiconfig_8.2/src/plesk/admin/work/apache_1.3.33/src/modules/php5; cp libs/libphp5.a //usr/home/builder/autobuilder/psa_aiconfig_8.2/src/plesk/admin/work/apache_1.3.33/src/modules/php5/libmodphp5.a; ranlib //usr/home/builder/autobuilder/psa_aiconfig_8.2/src/plesk/admin/work/apache_1.3.33/src/modules/php5/libmodphp5.a; cp $(srcdir)/sapi/apache/mod_php5.* sapi/apache/libphp5.module //usr/home/builder/autobuilder/psa_aiconfig_8.2/src/plesk/admin/work/apache_1.3.33/src/modules/php5; cp ./sapi/apache/apMakefile.tmpl //usr/home/builder/autobuilder/psa_aiconfig_8.2/src/plesk/admin/work/apache_1.3.33/src/modules/php5/Makefile.tmpl; cp ./sapi/apache/apMakefile.libdir //usr/home/builder/autobuilder/psa_aiconfig_8.2/src/plesk/admin/work/apache_1.3.33/src/modules/php5/Makefile.libdir"
#define PHP_IODBC_INCLUDE	""
#define PHP_IODBC_LFLAGS	""
#define PHP_IODBC_LIBS		""
#define PHP_MSQL_INCLUDE	""
#define PHP_MSQL_LFLAGS		""
#define PHP_MSQL_LIBS		""
#define PHP_MYSQL_INCLUDE	"-I/usr/local/include/mysql"
#define PHP_MYSQL_LIBS		"/usr/local/lib/mysql/libmysqlclient.a -lz -lcrypt -lm"
#define PHP_MYSQL_TYPE		"external"
#define PHP_ODBC_INCLUDE	""
#define PHP_ODBC_LFLAGS		""
#define PHP_ODBC_LIBS		""
#define PHP_ODBC_TYPE		""
#define PHP_OCI8_SHARED_LIBADD 	""
#define PHP_OCI8_DIR			""
#define PHP_OCI8_VERSION		""
#define PHP_ORACLE_SHARED_LIBADD 	""
#define PHP_ORACLE_DIR				""
#define PHP_ORACLE_VERSION			""
#define PHP_PGSQL_INCLUDE	""
#define PHP_PGSQL_LFLAGS	""
#define PHP_PGSQL_LIBS		""
#define PHP_PROG_SENDMAIL	"/usr/sbin/sendmail"
#define PHP_REGEX_LIB		""
#define PHP_SOLID_INCLUDE	""
#define PHP_SOLID_LIBS		""
#define PHP_EMPRESS_INCLUDE	""
#define PHP_EMPRESS_LIBS	""
#define PHP_SYBASE_INCLUDE	""
#define PHP_SYBASE_LFLAGS	""
#define PHP_SYBASE_LIBS		""
#define PHP_DBM_TYPE		""
#define PHP_DBM_LIB		""
#define PHP_LDAP_LFLAGS		""
#define PHP_LDAP_INCLUDE	""
#define PHP_LDAP_LIBS		""
#define PHP_BIRDSTEP_INCLUDE     ""
#define PHP_BIRDSTEP_LIBS        ""
#define PEAR_INSTALLDIR         ""
#define PHP_INCLUDE_PATH	".:"
#define PHP_EXTENSION_DIR       "/usr/local/psa/admin/lib/extensions/no-debug-non-zts-20041030"
#define PHP_PREFIX              "/usr/local/psa/admin"
#define PHP_BINDIR              "/usr/local/psa/admin/bin"
#define PHP_LIBDIR              "/usr/local/psa/admin/lib"
#define PHP_DATADIR             "${prefix}/share"
#define PHP_SYSCONFDIR          "/usr/local/psa/admin/etc"
#define PHP_LOCALSTATEDIR       "/usr/local/psa/admin/var"
#define PHP_CONFIG_FILE_PATH    "/usr/local/psa/admin/conf"
#define PHP_CONFIG_FILE_SCAN_DIR    ""
#define PHP_SHLIB_SUFFIX        "so"

==> psa-8.2.1.tar.gz: psa-8.2.1/psa/admin/include/php/main/build-defs.h <==
/*                                                                -*- C -*-
   +----------------------------------------------------------------------+
   | PHP Version 5                                                        |
   +----------------------------------------------------------------------+
   | Copyright (c) 1997-2004 The PHP Group                                |
   +----------------------------------------------------------------------+
   | This source file is subject to version 3.0 of the PHP license,       |
   | that is bundled with this package in the file LICENSE, and is        |
   | available through the world-wide-web at the following url:           |
   | http://www.php.net/license/3_0.txt.                                  |
   | If you did not receive a copy of the PHP license and are unable to   |
   | obtain it through the world-wide-web, please send a note to          |
   | license@php.net so we can mail you a copy immediately.               |
   +----------------------------------------------------------------------+
   | Author: Stig Sther Bakken <ssb@php.net>                             |
   +----------------------------------------------------------------------+
*/

/* $Id: build-defs.h.in,v 1.14 2004/01/08 17:33:04 sniper Exp $ */

#define CONFIGURE_COMMAND " './configure' '/usr/local/psa/admin/share/config.site' '/usr/local/psa/admin/etc/config.site'"
#define PHP_ADA_INCLUDE		""
#define PHP_ADA_LFLAGS		""
#define PHP_ADA_LIBS		""
#define PHP_APACHE_INCLUDE	""
#define PHP_APACHE_TARGET	""
#define PHP_FHTTPD_INCLUDE      ""
#define PHP_FHTTPD_LIB          ""
#define PHP_FHTTPD_TARGET       ""
#define PHP_CFLAGS		"$(CFLAGS_CLEAN) -prefer-non-pic -static"
#define PHP_DBASE_LIB		""
#define PHP_BUILD_DEBUG		""
#define PHP_GDBM_INCLUDE	""
#define PHP_HSREGEX		""
#define PHP_IBASE_INCLUDE	""
#define PHP_IBASE_LFLAGS	""
#define PHP_IBASE_LIBS		""
#define PHP_IFX_INCLUDE		""
#define PHP_IFX_LFLAGS		""
#define PHP_IFX_LIBS		""
#define PHP_INSTALL_IT		"mkdir -p //usr/home/builder/autobuilder/psa_aiconfig_8.2.1/src/plesk/admin/work/apache_1.3.33/src/modules/php5; cp libs/libphp5.a //usr/home/builder/autobuilder/psa_aiconfig_8.2.1/src/plesk/admin/work/apache_1.3.33/src/modules/php5/libmodphp5.a; ranlib //usr/home/builder/autobuilder/psa_aiconfig_8.2.1/src/plesk/admin/work/apache_1.3.33/src/modules/php5/libmodphp5.a; cp $(srcdir)/sapi/apache/mod_php5.* sapi/apache/libphp5.module //usr/home/builder/autobuilder/psa_aiconfig_8.2.1/src/plesk/admin/work/apache_1.3.33/src/modules/php5; cp ./sapi/apache/apMakefile.tmpl //usr/home/builder/autobuilder/psa_aiconfig_8.2.1/src/plesk/admin/work/apache_1.3.33/src/modules/php5/Makefile.tmpl; cp ./sapi/apache/apMakefile.libdir //usr/home/builder/autobuilder/psa_aiconfig_8.2.1/src/plesk/admin/work/apache_1.3.33/src/modules/php5/Makefile.libdir"
#define PHP_IODBC_INCLUDE	""
#define PHP_IODBC_LFLAGS	""
#define PHP_IODBC_LIBS		""
#define PHP_MSQL_INCLUDE	""
#define PHP_MSQL_LFLAGS		""
#define PHP_MSQL_LIBS		""
#define PHP_MYSQL_INCLUDE	"-I/usr/local/include/mysql"
#define PHP_MYSQL_LIBS		"/usr/local/lib/mysql/libmysqlclient.a -lz -lcrypt -lm"
#define PHP_MYSQL_TYPE		"external"
#define PHP_ODBC_INCLUDE	""
#define PHP_ODBC_LFLAGS		""
#define PHP_ODBC_LIBS		""
#define PHP_ODBC_TYPE		""
#define PHP_OCI8_SHARED_LIBADD 	""
#define PHP_OCI8_DIR			""
#define PHP_OCI8_VERSION		""
#define PHP_ORACLE_SHARED_LIBADD 	""
#define PHP_ORACLE_DIR				""
#define PHP_ORACLE_VERSION			""
#define PHP_PGSQL_INCLUDE	""
#define PHP_PGSQL_LFLAGS	""
#define PHP_PGSQL_LIBS		""
#define PHP_PROG_SENDMAIL	"/usr/sbin/sendmail"
#define PHP_REGEX_LIB		""
#define PHP_SOLID_INCLUDE	""
#define PHP_SOLID_LIBS		""
#define PHP_EMPRESS_INCLUDE	""
#define PHP_EMPRESS_LIBS	""
#define PHP_SYBASE_INCLUDE	""
#define PHP_SYBASE_LFLAGS	""
#define PHP_SYBASE_LIBS		""
#define PHP_DBM_TYPE		""
#define PHP_DBM_LIB		""
#define PHP_LDAP_LFLAGS		""
#define PHP_LDAP_INCLUDE	""
#define PHP_LDAP_LIBS		""
#define PHP_BIRDSTEP_INCLUDE     ""
#define PHP_BIRDSTEP_LIBS        ""
#define PEAR_INSTALLDIR         ""
#define PHP_INCLUDE_PATH	".:"
#define PHP_EXTENSION_DIR       "/usr/local/psa/admin/lib/extensions/no-debug-non-zts-20041030"
#define PHP_PREFIX              "/usr/local/psa/admin"
#define PHP_BINDIR              "/usr/local/psa/admin/bin"
#define PHP_LIBDIR              "/usr/local/psa/admin/lib"
#define PHP_DATADIR             "${prefix}/share"
#define PHP_SYSCONFDIR          "/usr/local/psa/admin/etc"
#define PHP_LOCALSTATEDIR       "/usr/local/psa/admin/var"
#define PHP_CONFIG_FILE_PATH    "/usr/local/psa/admin/conf"
#define PHP_CONFIG_FILE_SCAN_DIR    ""
#define PHP_SHLIB_SUFFIX        "so"
